#!/bin/sh

# This runs as setuid if it:
#  1) is owned by root
#  2) has o+r, g+r permissions
#  3) is located in /usr/share/klink, which is itself owned by root.

echo "Running Klink down script"

IFACE=$1
IFACE_FILE=/etc/network/interfaces

if [ -z $IFACE ]; then
	echo "Klink down script: no interface specified"
	exit 1
fi

# Bring down the interface if NetworkManager is not handling the
# interface (Ubuntu 13.10).
PID_FILE=dhclient.$IFACE.pid
PID_FILEPATH=/run/$PID_FILE
if [ ! -f $PID_FILEPATH ]; then
	PID_FILEPATH=/var/run/$PID_FILE
fi
if [ -f $PID_FILEPATH ]; then
	PID=`cat $PID_FILEPATH`
	echo "Sending SIGTERM to dhclient ($PID) to clean it up."
	kill -15 $PID

	rm $PID_FILEPATH
fi

# Clean up the ifup status file explicitly, since ifdown doesn't always work
# from this context.
IFUPDOWN_PATH=/run/network
if [ ! -d $IFUPDOWN_PATH ]; then
	IFUPDOWN_PATH=/var/run/network
fi

IF_FILE=$IFUPDOWN_PATH/ifup.$IFACE
if [ -f $IF_FILE ]; then
	echo "Cleaning up ifupdown state for $IFACE"
	rm $IF_FILE
fi

IFSTATE_FILE=$IFUPDOWN_PATH/ifstate
if [ -f $IFSTATE_FILE ]; then
	# Remove:
	#  klink0=klink0
	#
	# Also clean up any single leading newline.
	sed -i -e '/^[[:space:]]*$/N' -e "/^[\n[:space:]]*$IFACE=$IFACE\>/d" $IFSTATE_FILE
fi

# Reverse the configuration changes from klink-up.sh.
if [ -f $IFACE_FILE ] ; then
	# Remove:
	#  iface klink0 inet dhcp
	#  auto klink0
	#
	# Also clean up any single leading newline.
	sed -i -e '/^[[:space:]]*$/N' -e "/^[\n[:space:]]*iface[[:space:]]\+$IFACE[[:space:]]\+inet[[:space:]]\+dhcp\>/d" -e "/^[\n[:space:]]*auto[[:space:]].*$IFACE\>/d" $IFACE_FILE
fi

# Clean up resolv.conf in case ifdown was not called in time.  This would
# happen if the client were to receive a SIGINT/SIGKILL signal.
RESOLVCONF=/sbin/resolvconf

if [ -f $RESOLVCONF ]; then
	$RESOLVCONF -d $IFACE.dhclient
	$RESOLVCONF -d $IFACE.inet
fi

exit 0
