#!/bin/sh

# This runs as setuid if it:
#  1) is owned by root
#  2) has o+r, g+r permissions
#  3) is located in /usr/share/klink, which is itself owned by root.

echo "Running Klink up script"

IFACE=$1
IFACE_FILE=/etc/network/interfaces

if [ -z $IFACE ]; then
	echo "Klink up script: no interface specified"
	exit 1
fi

# Configure the interface so that it will be handled by ifupdown
# for those versions of NetworkManager that do not correctly recognize TAP
# network devices (like the one installed with Ubuntu 13.10).

if [ -f $IFACE_FILE ] ; then
	if ! grep -q "^[[:space:]]*iface[[:space:]]\+$IFACE[[:space:]]\+inet[[:space:]]\+dhcp\>" $IFACE_FILE ; then
		# No "iface klink0 inet dhcp" definition.
		if ! grep -q "^[[:space:]]*auto[[:space:]].*\<$IFACE\>" $IFACE_FILE ; then
			# No "auto klink0" definition.  Add both.
			cat >> $IFACE_FILE << EOF

auto $IFACE
iface $IFACE inet dhcp
EOF
		else
			# Have "auto klink0", so just add the missing
			# "iface klink0 inet dhcp"
			sed -i -e "/^[[:space:]]*auto[[:space:]].*\<$IFACE\>/a\
iface $IFACE inet dhcp" $IFACE_FILE
		fi
	else
		# Have "iface klink0 inet dhcp"
		if ! grep -q "^[[:space:]]*auto[[:space:]].*\<$IFACE\>" $IFACE_FILE ; then
			# Add the "auto klink0"
			sed -i -e "/^[[:space:]]*iface[[:space:]]\+$IFACE[[:space:]]\+inet[[:space:]]\+dhcp\>/i\
auto $IFACE" $IFACE_FILE
		fi
	fi
fi

# Removes the auto interface line to prevent delays when booting if Klink
# is cleaned abruptly.  This is necessary, since the interface does not exist
# unless klink is running.
reset_auto_interface() {
	sed -i -e '/^[[:space:]]*$/N' -e "/^[\n[:space:]]*auto[[:space:]].*$IFACE\>/d" $IFACE_FILE
}

# Clean up the configs after some seconds to prevent problems if
# Klink is SIGKILLed.
sleep 5 && reset_auto_interface &

exit 0
